@@ -243,7 +243,7 @@ private:
 	void linkToEditorSlot(QAction *act, const char *slot, const QList<QVariant> &args);
 
     bool parseStruct(LatexDocument *doc, QVector<QTreeWidgetItem *> &rootVector, QSet<LatexDocument*> *visited=nullptr, QList<QTreeWidgetItem *> *todoList=nullptr, int currentColor=0);
-    void parseStructLocally(LatexDocument* document, QVector<QTreeWidgetItem *> &rootVector, QList<QTreeWidgetItem *> *todoList=nullptr, QList<QTreeWidgetItem *> *labelList=nullptr, QList<QTreeWidgetItem *> *magicList=nullptr, QList<QTreeWidgetItem *> *biblioList=nullptr);
+    void parseStructLocally(LatexDocument* document, QVector<QTreeWidgetItem *> &rootVector, QList<QTreeWidgetItem *> *todoList=nullptr, QList<QTreeWidgetItem *> *labelList=nullptr, QList<QTreeWidgetItem *> *magicList=nullptr, QList<QTreeWidgetItem *> *biblioList=nullptr, QList<QTreeWidgetItem *> *blockList=nullptr);
 #ifndef QT_NO_DEBUG
     void checkForShortcutDuplicate();
 #endif
@@ -560,6 +560,7 @@ protected slots:
 	void focusViewer();
 	void enlargeEmbeddedPDFViewer();
 	void shrinkEmbeddedPDFViewer(bool preserveConfig = false);
+	void setEnabledMenusEnlargeShrink(bool enabledEnlarge, bool enabledShrink);
 
 	void showStatusbar();
 	void viewCloseElement();
@@ -749,6 +750,7 @@ public slots:
     void resetDocks();
     void toggleDockVisibility();
     void updateDockVisibility(bool visible);
+    bool checkDockSpread();
 
 signals:
 	void infoNewFile(); ///< signal that a new file has been generated. Used for scritps as trigger.
